/**
    @file ft51_pwm_registers.h

    @brief PWM registers library

    Defines registers and bit-masks for Pulse-Width Modulation.

    @version 1.0.0

**/
/*
 * ============================================================================
 * History
 * =======
 *
 * (C) Copyright 2014, Future Technology Devices International Ltd.
 * ============================================================================
 *
 * This source code ("the Software") is provided by Future Technology Devices
 * International Limited ("FTDI") subject to the licence terms set out
 * http://www.ftdichip.com/FTSourceCodeLicenceTerms.htm ("the Licence Terms").
 * You must read the Licence Terms before downloading or using the Software.
 * By installing or using the Software you agree to the Licence Terms. If you
 * do not agree to the Licence Terms then do not download or use the Software.
 *
 * Without prejudice to the Licence Terms, here is a summary of some of the key
 * terms of the Licence Terms (and in the event of any conflict between this
 * summary and the Licence Terms then the text of the Licence Terms will
 * prevail).
 *
 * The Software is provided "as is".
 * There are no warranties (or similar) in relation to the quality of the
 * Software. You use it at your own risk.
 * The Software should not be used in, or for, any medical device, system or
 * appliance. There are exclusions of FTDI liability for certain types of loss
 * such as: special loss or damage; incidental loss or damage; indirect or
 * consequential loss or damage; loss of income; loss of business; loss of
 * profits; loss of revenue; loss of contracts; business interruption; loss of
 * the use of money or anticipated savings; loss of information; loss of
 * opportunity; loss of goodwill or reputation; and/or loss of, damage to or
 * corruption of data.
 * There is a monetary cap on FTDI's liability.
 * The Software may have subsequently been amended by another user and then
 * distributed by that other user ("Adapted Software").  If so that user may
 * have additional licence terms that apply to those amendments. However, FTDI
 * has no liability in relation to those amendments.
 * ============================================================================
 */

#ifndef __FT51_PWM_REGISTERS_H__
#define __FT51_PWM_REGISTERS_H__

//------------------------------------------------------------------------------
// Register 128 (0x80) PWM_CONTROL
#define PWM_CONTROL                           0x80

// Register 128 Bit Definitions
#define BIT_PWM_SOFT_RESET                    0                                 // Write a 1 to reset PWM
#define MASK_PWM_SOFT_RESET                   (0x1 << BIT_PWM_SOFT_RESET)
#define BIT_PWM_DEV_EN                        1                                 // Write a 1 to enable PWM
#define MASK_PWM_DEV_EN                       (0x1 << BIT_PWM_DEV_EN)

//------------------------------------------------------------------------------
// Register 129 (0x81) PWM_INT_CTRL
#define PWM_INT_CTRL                            0x81

// Register 129 Bit Definitions
#define BIT_PWM_EN                            0                                 // PWM enable. Write '1' to enable -connected to control block
#define MASK_PWM_EN                           (0x1 << BIT_PWM_EN)
#define BIT_PWM_TRIGGER_EN_0                  1                                 // PWM trigger enable: 00 disabled 01 positive edge 01 negative edge 11 any edge
#define MASK_PWM_TRIGGER_EN_0                 (0x1 << BIT_PWM_TRIGGER_EN_0)
#define BIT_PWM_TRIGGER_EN_1                  2                                 // PWM trigger enable: 00 disabled 01 positive edge 01 negative edge 11 any edge
#define MASK_PWM_TRIGGER_EN_1                 (0x1 << BIT_PWM_TRIGGER_EN_1)
#define MASK_PWM_TRIGGER_EN                   (0x3 << BIT_PWM_TRIGGER_EN_0)
#define BIT_PWM_BUSY                          3                                 // PWM busy
#define MASK_PWM_BUSY                         (0x1 << BIT_PWM_BUSY)
#define BIT_PWM_INT_IEN                       4                                 // PWM interrupt enable for pwm_int
#define MASK_PWM_INT_IEN                      (0x1 << BIT_PWM_INT_IEN)
#define BIT_PWM_INT                           5                                 // PWM interrupt
#define MASK_PWM_INT                          (0x1 << BIT_PWM_INT)

//------------------------------------------------------------------------------
// Register 130 (0x82) PWM_PRESCALER
#define PWM_PRESCALER                       0x82

// Register 130 Bit Definitions
#define BIT_PRESCALER_0                       0                                 // Prescaler CMP8 value
#define MASK_PRESCALER_0                      (0x1 << BIT_PRESCALER_0)
#define BIT_PRESCALER_1                       1                                 // Prescaler CMP8 value
#define MASK_PRESCALER_1                      (0x1 << BIT_PRESCALER_1)
#define BIT_PRESCALER_2                       2                                 // Prescaler CMP8 value
#define MASK_PRESCALER_2                      (0x1 << BIT_PRESCALER_2)
#define BIT_PRESCALER_3                       3                                 // Prescaler CMP8 value
#define MASK_PRESCALER_3                      (0x1 << BIT_PRESCALER_3)
#define BIT_PRESCALER_4                       4                                 // Prescaler CMP8 value
#define MASK_PRESCALER_4                      (0x1 << BIT_PRESCALER_4)
#define BIT_PRESCALER_5                       5                                 // Prescaler CMP8 value
#define MASK_PRESCALER_5                      (0x1 << BIT_PRESCALER_5)
#define BIT_PRESCALER_6                       6                                 // Prescaler CMP8 value
#define MASK_PRESCALER_6                      (0x1 << BIT_PRESCALER_6)
#define BIT_PRESCALER_7                       7                                 // Prescaler CMP8 value
#define MASK_PRESCALER_7                      (0x1 << BIT_PRESCALER_7)
#define MASK_PRESCALER                        (0xFF << BIT_PRESCALER_0)

//------------------------------------------------------------------------------
// Register 131 (0x83) PWM_CNT16_LSB
#define PWM_CNT16_LSB                       0x83

// Register 131 Bit Definitions
#define BIT_CNT16_LSB_0                       0                                 // CMP16 LSB
#define MASK_CNT16_LSB_0                      (0x1 << BIT_CNT16_LSB_0)
#define BIT_CNT16_LSB_1                       1                                 // CMP16 LSB
#define MASK_CNT16_LSB_1                      (0x1 << BIT_CNT16_LSB_1)
#define BIT_CNT16_LSB_2                       2                                 // CMP16 LSB
#define MASK_CNT16_LSB_2                      (0x1 << BIT_CNT16_LSB_2)
#define BIT_CNT16_LSB_3                       3                                 // CMP16 LSB
#define MASK_CNT16_LSB_3                      (0x1 << BIT_CNT16_LSB_3)
#define BIT_CNT16_LSB_4                       4                                 // CMP16 LSB
#define MASK_CNT16_LSB_4                      (0x1 << BIT_CNT16_LSB_4)
#define BIT_CNT16_LSB_5                       5                                 // CMP16 LSB
#define MASK_CNT16_LSB_5                      (0x1 << BIT_CNT16_LSB_5)
#define BIT_CNT16_LSB_6                       6                                 // CMP16 LSB
#define MASK_CNT16_LSB_6                      (0x1 << BIT_CNT16_LSB_6)
#define BIT_CNT16_LSB_7                       7                                 // CMP16 LSB
#define MASK_CNT16_LSB_7                      (0x1 << BIT_CNT16_LSB_7)
#define MASK_CNT16_LSB                        (0xFF << BIT_CNT16_LSB_0)

//------------------------------------------------------------------------------
// Register 132 (0x84) PWM_CNT16_MSB
#define PWM_CNT16_MSB                       0x84

// Register 132 Bit Definitions
#define BIT_CNT16_MSB_0                       0                                 // CMP16 MSB
#define MASK_CNT16_MSB_0                      (0x1 << BIT_CNT16_MSB_0)
#define BIT_CNT16_MSB_1                       1                                 // CMP16 MSB
#define MASK_CNT16_MSB_1                      (0x1 << BIT_CNT16_MSB_1)
#define BIT_CNT16_MSB_2                       2                                 // CMP16 MSB
#define MASK_CNT16_MSB_2                      (0x1 << BIT_CNT16_MSB_2)
#define BIT_CNT16_MSB_3                       3                                 // CMP16 MSB
#define MASK_CNT16_MSB_3                      (0x1 << BIT_CNT16_MSB_3)
#define BIT_CNT16_MSB_4                       4                                 // CMP16 MSB
#define MASK_CNT16_MSB_4                      (0x1 << BIT_CNT16_MSB_4)
#define BIT_CNT16_MSB_5                       5                                 // CMP16 MSB
#define MASK_CNT16_MSB_5                      (0x1 << BIT_CNT16_MSB_5)
#define BIT_CNT16_MSB_6                       6                                 // CMP16 MSB
#define MASK_CNT16_MSB_6                      (0x1 << BIT_CNT16_MSB_6)
#define BIT_CNT16_MSB_7                       7                                 // CMP16 MSB
#define MASK_CNT16_MSB_7                      (0x1 << BIT_CNT16_MSB_7)
#define MASK_CNT16_MSB                        (0xFF << BIT_CNT16_MSB_0)

//------------------------------------------------------------------------------
// Register 133 (0x85) PWM_CMP16_0_LSB
#define PWM_CMP16_0_LSB                     0x85

// Register 133 Bit Definitions
#define BIT_CMP16_0_LSB_0                     0                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_0                    (0x1 << BIT_CMP16_0_LSB_0)
#define BIT_CMP16_0_LSB_1                     1                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_1                    (0x1 << BIT_CMP16_0_LSB_1)
#define BIT_CMP16_0_LSB_2                     2                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_2                    (0x1 << BIT_CMP16_0_LSB_2)
#define BIT_CMP16_0_LSB_3                     3                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_3                    (0x1 << BIT_CMP16_0_LSB_3)
#define BIT_CMP16_0_LSB_4                     4                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_4                    (0x1 << BIT_CMP16_0_LSB_4)
#define BIT_CMP16_0_LSB_5                     5                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_5                    (0x1 << BIT_CMP16_0_LSB_5)
#define BIT_CMP16_0_LSB_6                     6                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_6                    (0x1 << BIT_CMP16_0_LSB_6)
#define BIT_CMP16_0_LSB_7                     7                                 // CMP16_0 LSB
#define MASK_CMP16_0_LSB_7                    (0x1 << BIT_CMP16_0_LSB_7)
#define MASK_CMP16_0_LSB                      (0xFF << BIT_CMP16_0_LSB_0)

//------------------------------------------------------------------------------
// Register 134 (0x86) PWM_CMP16_0_MSB
#define PWM_CMP16_0_MSB                     0x86

// Register 134 Bit Definitions
#define BIT_CMP16_0_MSB_0                     0                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_0                    (0x1 << BIT_CMP16_0_MSB_0)
#define BIT_CMP16_0_MSB_1                     1                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_1                    (0x1 << BIT_CMP16_0_MSB_1)
#define BIT_CMP16_0_MSB_2                     2                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_2                    (0x1 << BIT_CMP16_0_MSB_2)
#define BIT_CMP16_0_MSB_3                     3                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_3                    (0x1 << BIT_CMP16_0_MSB_3)
#define BIT_CMP16_0_MSB_4                     4                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_4                    (0x1 << BIT_CMP16_0_MSB_4)
#define BIT_CMP16_0_MSB_5                     5                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_5                    (0x1 << BIT_CMP16_0_MSB_5)
#define BIT_CMP16_0_MSB_6                     6                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_6                    (0x1 << BIT_CMP16_0_MSB_6)
#define BIT_CMP16_0_MSB_7                     7                                 // CMP16_0 MSB
#define MASK_CMP16_0_MSB_7                    (0x1 << BIT_CMP16_0_MSB_7)
#define MASK_CMP16_0_MSB                      (0xFF << BIT_CMP16_0_MSB_0)

//------------------------------------------------------------------------------
// Register 135 (0x87) PWM_CMP16_1_LSB
#define PWM_CMP16_1_LSB                     0x87

// Register 135 Bit Definitions
#define BIT_CMP16_1_LSB_0                     0                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_0                    (0x1 << BIT_CMP16_1_LSB_0)
#define BIT_CMP16_1_LSB_1                     1                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_1                    (0x1 << BIT_CMP16_1_LSB_1)
#define BIT_CMP16_1_LSB_2                     2                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_2                    (0x1 << BIT_CMP16_1_LSB_2)
#define BIT_CMP16_1_LSB_3                     3                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_3                    (0x1 << BIT_CMP16_1_LSB_3)
#define BIT_CMP16_1_LSB_4                     4                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_4                    (0x1 << BIT_CMP16_1_LSB_4)
#define BIT_CMP16_1_LSB_5                     5                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_5                    (0x1 << BIT_CMP16_1_LSB_5)
#define BIT_CMP16_1_LSB_6                     6                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_6                    (0x1 << BIT_CMP16_1_LSB_6)
#define BIT_CMP16_1_LSB_7                     7                                 // CMP16_1 LSB
#define MASK_CMP16_1_LSB_7                    (0x1 << BIT_CMP16_1_LSB_7)
#define MASK_CMP16_1_LSB                      (0xFF << BIT_CMP16_1_LSB_0)

//------------------------------------------------------------------------------
// Register 136 (0x88) PWM_CMP16_1_MSB
#define PWM_CMP16_1_MSB                     0x88

// Register 136 Bit Definitions
#define BIT_CMP16_1_MSB_0                     0                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_0                    (0x1 << BIT_CMP16_1_MSB_0)
#define BIT_CMP16_1_MSB_1                     1                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_1                    (0x1 << BIT_CMP16_1_MSB_1)
#define BIT_CMP16_1_MSB_2                     2                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_2                    (0x1 << BIT_CMP16_1_MSB_2)
#define BIT_CMP16_1_MSB_3                     3                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_3                    (0x1 << BIT_CMP16_1_MSB_3)
#define BIT_CMP16_1_MSB_4                     4                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_4                    (0x1 << BIT_CMP16_1_MSB_4)
#define BIT_CMP16_1_MSB_5                     5                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_5                    (0x1 << BIT_CMP16_1_MSB_5)
#define BIT_CMP16_1_MSB_6                     6                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_6                    (0x1 << BIT_CMP16_1_MSB_6)
#define BIT_CMP16_1_MSB_7                     7                                 // CMP16_1 MSB
#define MASK_CMP16_1_MSB_7                    (0x1 << BIT_CMP16_1_MSB_7)
#define MASK_CMP16_1_MSB                      (0xFF << BIT_CMP16_1_MSB_0)

//------------------------------------------------------------------------------
// Register 137 (0x89) PWM_CMP16_2_LSB
#define PWM_CMP16_2_LSB                     0x89

// Register 137 Bit Definitions
#define BIT_CMP16_2_LSB_0                     0                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_0                    (0x1 << BIT_CMP16_2_LSB_0)
#define BIT_CMP16_2_LSB_1                     1                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_1                    (0x1 << BIT_CMP16_2_LSB_1)
#define BIT_CMP16_2_LSB_2                     2                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_2                    (0x1 << BIT_CMP16_2_LSB_2)
#define BIT_CMP16_2_LSB_3                     3                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_3                    (0x1 << BIT_CMP16_2_LSB_3)
#define BIT_CMP16_2_LSB_4                     4                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_4                    (0x1 << BIT_CMP16_2_LSB_4)
#define BIT_CMP16_2_LSB_5                     5                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_5                    (0x1 << BIT_CMP16_2_LSB_5)
#define BIT_CMP16_2_LSB_6                     6                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_6                    (0x1 << BIT_CMP16_2_LSB_6)
#define BIT_CMP16_2_LSB_7                     7                                 // CMP16_2 LSB
#define MASK_CMP16_2_LSB_7                    (0x1 << BIT_CMP16_2_LSB_7)
#define MASK_CMP16_2_LSB                      (0xFF << BIT_CMP16_2_LSB_0)

//------------------------------------------------------------------------------
// Register 138 (0x8A) PWM_CMP16_2_MSB
#define PWM_CMP16_2_MSB                     0x8A

// Register 138 Bit Definitions
#define BIT_CMP16_2_MSB_0                     0                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_0                    (0x1 << BIT_CMP16_2_MSB_0)
#define BIT_CMP16_2_MSB_1                     1                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_1                    (0x1 << BIT_CMP16_2_MSB_1)
#define BIT_CMP16_2_MSB_2                     2                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_2                    (0x1 << BIT_CMP16_2_MSB_2)
#define BIT_CMP16_2_MSB_3                     3                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_3                    (0x1 << BIT_CMP16_2_MSB_3)
#define BIT_CMP16_2_MSB_4                     4                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_4                    (0x1 << BIT_CMP16_2_MSB_4)
#define BIT_CMP16_2_MSB_5                     5                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_5                    (0x1 << BIT_CMP16_2_MSB_5)
#define BIT_CMP16_2_MSB_6                     6                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_6                    (0x1 << BIT_CMP16_2_MSB_6)
#define BIT_CMP16_2_MSB_7                     7                                 // CMP16_2 MSB
#define MASK_CMP16_2_MSB_7                    (0x1 << BIT_CMP16_2_MSB_7)
#define MASK_CMP16_2_MSB                      (0xFF << BIT_CMP16_2_MSB_0)

//------------------------------------------------------------------------------
// Register 139 (0x8B) PWM_CMP16_3_LSB
#define PWM_CMP16_3_LSB                     0x8B

// Register 139 Bit Definitions
#define BIT_CMP16_3_LSB_0                     0                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_0                    (0x1 << BIT_CMP16_3_LSB_0)
#define BIT_CMP16_3_LSB_1                     1                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_1                    (0x1 << BIT_CMP16_3_LSB_1)
#define BIT_CMP16_3_LSB_2                     2                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_2                    (0x1 << BIT_CMP16_3_LSB_2)
#define BIT_CMP16_3_LSB_3                     3                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_3                    (0x1 << BIT_CMP16_3_LSB_3)
#define BIT_CMP16_3_LSB_4                     4                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_4                    (0x1 << BIT_CMP16_3_LSB_4)
#define BIT_CMP16_3_LSB_5                     5                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_5                    (0x1 << BIT_CMP16_3_LSB_5)
#define BIT_CMP16_3_LSB_6                     6                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_6                    (0x1 << BIT_CMP16_3_LSB_6)
#define BIT_CMP16_3_LSB_7                     7                                 // CMP16_3 LSB
#define MASK_CMP16_3_LSB_7                    (0x1 << BIT_CMP16_3_LSB_7)
#define MASK_CMP16_3_LSB                      (0xFF << BIT_CMP16_3_LSB_0)

//------------------------------------------------------------------------------
// Register 140 (0x8C) PWM_CMP16_3_MSB
#define PWM_CMP16_3_MSB                     0x8C

// Register 140 Bit Definitions
#define BIT_CMP16_3_MSB_0                     0                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_0                    (0x1 << BIT_CMP16_3_MSB_0)
#define BIT_CMP16_3_MSB_1                     1                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_1                    (0x1 << BIT_CMP16_3_MSB_1)
#define BIT_CMP16_3_MSB_2                     2                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_2                    (0x1 << BIT_CMP16_3_MSB_2)
#define BIT_CMP16_3_MSB_3                     3                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_3                    (0x1 << BIT_CMP16_3_MSB_3)
#define BIT_CMP16_3_MSB_4                     4                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_4                    (0x1 << BIT_CMP16_3_MSB_4)
#define BIT_CMP16_3_MSB_5                     5                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_5                    (0x1 << BIT_CMP16_3_MSB_5)
#define BIT_CMP16_3_MSB_6                     6                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_6                    (0x1 << BIT_CMP16_3_MSB_6)
#define BIT_CMP16_3_MSB_7                     7                                 // CMP16_3 MSB
#define MASK_CMP16_3_MSB_7                    (0x1 << BIT_CMP16_3_MSB_7)
#define MASK_CMP16_3_MSB                      (0xFF << BIT_CMP16_3_MSB_0)

//------------------------------------------------------------------------------
// Register 141 (0x8D) PWM_CMP16_4_LSB
#define PWM_CMP16_4_LSB                     0x8D

// Register 141 Bit Definitions
#define BIT_CMP16_4_LSB_0                     0                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_0                    (0x1 << BIT_CMP16_4_LSB_0)
#define BIT_CMP16_4_LSB_1                     1                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_1                    (0x1 << BIT_CMP16_4_LSB_1)
#define BIT_CMP16_4_LSB_2                     2                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_2                    (0x1 << BIT_CMP16_4_LSB_2)
#define BIT_CMP16_4_LSB_3                     3                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_3                    (0x1 << BIT_CMP16_4_LSB_3)
#define BIT_CMP16_4_LSB_4                     4                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_4                    (0x1 << BIT_CMP16_4_LSB_4)
#define BIT_CMP16_4_LSB_5                     5                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_5                    (0x1 << BIT_CMP16_4_LSB_5)
#define BIT_CMP16_4_LSB_6                     6                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_6                    (0x1 << BIT_CMP16_4_LSB_6)
#define BIT_CMP16_4_LSB_7                     7                                 // CMP16_4 LSB
#define MASK_CMP16_4_LSB_7                    (0x1 << BIT_CMP16_4_LSB_7)
#define MASK_CMP16_4_LSB                      (0xFF << BIT_CMP16_4_LSB_0)

//------------------------------------------------------------------------------
// Register 142 (0x8E) PWM_CMP16_4_MSB
#define PWM_CMP16_4_MSB                     0x8E

// Register 142 Bit Definitions
#define BIT_CMP16_4_MSB_0                     0                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_0                    (0x1 << BIT_CMP16_4_MSB_0)
#define BIT_CMP16_4_MSB_1                     1                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_1                    (0x1 << BIT_CMP16_4_MSB_1)
#define BIT_CMP16_4_MSB_2                     2                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_2                    (0x1 << BIT_CMP16_4_MSB_2)
#define BIT_CMP16_4_MSB_3                     3                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_3                    (0x1 << BIT_CMP16_4_MSB_3)
#define BIT_CMP16_4_MSB_4                     4                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_4                    (0x1 << BIT_CMP16_4_MSB_4)
#define BIT_CMP16_4_MSB_5                     5                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_5                    (0x1 << BIT_CMP16_4_MSB_5)
#define BIT_CMP16_4_MSB_6                     6                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_6                    (0x1 << BIT_CMP16_4_MSB_6)
#define BIT_CMP16_4_MSB_7                     7                                 // CMP16_4 MSB
#define MASK_CMP16_4_MSB_7                    (0x1 << BIT_CMP16_4_MSB_7)
#define MASK_CMP16_4_MSB                      (0xFF << BIT_CMP16_4_MSB_0)

//------------------------------------------------------------------------------
// Register 143 (0x8F) PWM_CMP16_5_LSB
#define PWM_CMP16_5_LSB                     0x8F

// Register 143 Bit Definitions
#define BIT_CMP16_5_LSB_0                     0                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_0                    (0x1 << BIT_CMP16_5_LSB_0)
#define BIT_CMP16_5_LSB_1                     1                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_1                    (0x1 << BIT_CMP16_5_LSB_1)
#define BIT_CMP16_5_LSB_2                     2                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_2                    (0x1 << BIT_CMP16_5_LSB_2)
#define BIT_CMP16_5_LSB_3                     3                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_3                    (0x1 << BIT_CMP16_5_LSB_3)
#define BIT_CMP16_5_LSB_4                     4                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_4                    (0x1 << BIT_CMP16_5_LSB_4)
#define BIT_CMP16_5_LSB_5                     5                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_5                    (0x1 << BIT_CMP16_5_LSB_5)
#define BIT_CMP16_5_LSB_6                     6                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_6                    (0x1 << BIT_CMP16_5_LSB_6)
#define BIT_CMP16_5_LSB_7                     7                                 // CMP16_5 LSB
#define MASK_CMP16_5_LSB_7                    (0x1 << BIT_CMP16_5_LSB_7)
#define MASK_CMP16_5_LSB                      (0xFF << BIT_CMP16_5_LSB_0)

//------------------------------------------------------------------------------
// Register 144 (0x90) PWM_CMP16_5_MSB
#define PWM_CMP16_5_MSB                     0x90

// Register 144 Bit Definitions
#define BIT_CMP16_5_MSB_0                     0                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_0                    (0x1 << BIT_CMP16_5_MSB_0)
#define BIT_CMP16_5_MSB_1                     1                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_1                    (0x1 << BIT_CMP16_5_MSB_1)
#define BIT_CMP16_5_MSB_2                     2                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_2                    (0x1 << BIT_CMP16_5_MSB_2)
#define BIT_CMP16_5_MSB_3                     3                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_3                    (0x1 << BIT_CMP16_5_MSB_3)
#define BIT_CMP16_5_MSB_4                     4                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_4                    (0x1 << BIT_CMP16_5_MSB_4)
#define BIT_CMP16_5_MSB_5                     5                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_5                    (0x1 << BIT_CMP16_5_MSB_5)
#define BIT_CMP16_5_MSB_6                     6                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_6                    (0x1 << BIT_CMP16_5_MSB_6)
#define BIT_CMP16_5_MSB_7                     7                                 // CMP16_5 MSB
#define MASK_CMP16_5_MSB_7                    (0x1 << BIT_CMP16_5_MSB_7)
#define MASK_CMP16_5_MSB                      (0xFF << BIT_CMP16_5_MSB_0)

//------------------------------------------------------------------------------
// Register 145 (0x91) PWM_CMP16_6_LSB
#define PWM_CMP16_6_LSB                     0x91

// Register 145 Bit Definitions
#define BIT_CMP16_6_LSB_0                     0                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_0                    (0x1 << BIT_CMP16_6_LSB_0)
#define BIT_CMP16_6_LSB_1                     1                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_1                    (0x1 << BIT_CMP16_6_LSB_1)
#define BIT_CMP16_6_LSB_2                     2                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_2                    (0x1 << BIT_CMP16_6_LSB_2)
#define BIT_CMP16_6_LSB_3                     3                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_3                    (0x1 << BIT_CMP16_6_LSB_3)
#define BIT_CMP16_6_LSB_4                     4                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_4                    (0x1 << BIT_CMP16_6_LSB_4)
#define BIT_CMP16_6_LSB_5                     5                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_5                    (0x1 << BIT_CMP16_6_LSB_5)
#define BIT_CMP16_6_LSB_6                     6                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_6                    (0x1 << BIT_CMP16_6_LSB_6)
#define BIT_CMP16_6_LSB_7                     7                                 // CMP16_6 LSB
#define MASK_CMP16_6_LSB_7                    (0x1 << BIT_CMP16_6_LSB_7)
#define MASK_CMP16_6_LSB                      (0xFF << BIT_CMP16_6_LSB_0)

//------------------------------------------------------------------------------
// Register 146 (0x92) PWM_CMP16_6_MSB
#define PWM_CMP16_6_MSB                     0x92

// Register 146 Bit Definitions
#define BIT_CMP16_6_MSB_0                     0                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_0                    (0x1 << BIT_CMP16_6_MSB_0)
#define BIT_CMP16_6_MSB_1                     1                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_1                    (0x1 << BIT_CMP16_6_MSB_1)
#define BIT_CMP16_6_MSB_2                     2                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_2                    (0x1 << BIT_CMP16_6_MSB_2)
#define BIT_CMP16_6_MSB_3                     3                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_3                    (0x1 << BIT_CMP16_6_MSB_3)
#define BIT_CMP16_6_MSB_4                     4                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_4                    (0x1 << BIT_CMP16_6_MSB_4)
#define BIT_CMP16_6_MSB_5                     5                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_5                    (0x1 << BIT_CMP16_6_MSB_5)
#define BIT_CMP16_6_MSB_6                     6                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_6                    (0x1 << BIT_CMP16_6_MSB_6)
#define BIT_CMP16_6_MSB_7                     7                                 // CMP16_6 MSB
#define MASK_CMP16_6_MSB_7                    (0x1 << BIT_CMP16_6_MSB_7)
#define MASK_CMP16_6_MSB                      (0xFF << BIT_CMP16_6_MSB_0)

//------------------------------------------------------------------------------
// Register 147 (0x93) PWM_CMP16_7_LSB
#define PWM_CMP16_7_LSB                     0x93

// Register 147 Bit Definitions
#define BIT_CMP16_7_LSB_0                     0                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_0                    (0x1 << BIT_CMP16_7_LSB_0)
#define BIT_CMP16_7_LSB_1                     1                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_1                    (0x1 << BIT_CMP16_7_LSB_1)
#define BIT_CMP16_7_LSB_2                     2                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_2                    (0x1 << BIT_CMP16_7_LSB_2)
#define BIT_CMP16_7_LSB_3                     3                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_3                    (0x1 << BIT_CMP16_7_LSB_3)
#define BIT_CMP16_7_LSB_4                     4                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_4                    (0x1 << BIT_CMP16_7_LSB_4)
#define BIT_CMP16_7_LSB_5                     5                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_5                    (0x1 << BIT_CMP16_7_LSB_5)
#define BIT_CMP16_7_LSB_6                     6                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_6                    (0x1 << BIT_CMP16_7_LSB_6)
#define BIT_CMP16_7_LSB_7                     7                                 // CMP16_7 LSB
#define MASK_CMP16_7_LSB_7                    (0x1 << BIT_CMP16_7_LSB_7)
#define MASK_CMP16_7_LSB                      (0xFF << BIT_CMP16_7_LSB_0)

//------------------------------------------------------------------------------
// Register 148 (0x94) PWM_CMP16_7_MSB
#define PWM_CMP16_7_MSB                     0x94

// Register 148 Bit Definitions
#define BIT_CMP16_7_MSB_0                     0                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_0                    (0x1 << BIT_CMP16_7_MSB_0)
#define BIT_CMP16_7_MSB_1                     1                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_1                    (0x1 << BIT_CMP16_7_MSB_1)
#define BIT_CMP16_7_MSB_2                     2                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_2                    (0x1 << BIT_CMP16_7_MSB_2)
#define BIT_CMP16_7_MSB_3                     3                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_3                    (0x1 << BIT_CMP16_7_MSB_3)
#define BIT_CMP16_7_MSB_4                     4                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_4                    (0x1 << BIT_CMP16_7_MSB_4)
#define BIT_CMP16_7_MSB_5                     5                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_5                    (0x1 << BIT_CMP16_7_MSB_5)
#define BIT_CMP16_7_MSB_6                     6                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_6                    (0x1 << BIT_CMP16_7_MSB_6)
#define BIT_CMP16_7_MSB_7                     7                                 // CMP16_7 MSB
#define MASK_CMP16_7_MSB_7                    (0x1 << BIT_CMP16_7_MSB_7)
#define MASK_CMP16_7_MSB                      (0xFF << BIT_CMP16_7_MSB_0)

//------------------------------------------------------------------------------
// Register 149 (0x95) PWM_OUT_TOGGLE_EN_0
#define PWM_OUT_TOGGLE_EN_0                 0x95

// Register 149 Bit Definitions
#define BIT_TOGGLE_EN_0_0                     0                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_0                    (0x1 << BIT_TOGGLE_EN_0_0)
#define BIT_TOGGLE_EN_0_1                     1                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_1                    (0x1 << BIT_TOGGLE_EN_0_1)
#define BIT_TOGGLE_EN_0_2                     2                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_2                    (0x1 << BIT_TOGGLE_EN_0_2)
#define BIT_TOGGLE_EN_0_3                     3                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_3                    (0x1 << BIT_TOGGLE_EN_0_3)
#define BIT_TOGGLE_EN_0_4                     4                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_4                    (0x1 << BIT_TOGGLE_EN_0_4)
#define BIT_TOGGLE_EN_0_5                     5                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_5                    (0x1 << BIT_TOGGLE_EN_0_5)
#define BIT_TOGGLE_EN_0_6                     6                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_6                    (0x1 << BIT_TOGGLE_EN_0_6)
#define BIT_TOGGLE_EN_0_7                     7                                 // PWM Out toggle enable 0
#define MASK_TOGGLE_EN_0_7                    (0x1 << BIT_TOGGLE_EN_0_7)
#define MASK_TOGGLE_EN_0                      (0xFF << BIT_TOGGLE_EN_0_0)

//------------------------------------------------------------------------------
// Register 150 (0x96) PWM_OUT_TOGGLE_EN_1
#define PWM_OUT_TOGGLE_EN_1                 0x96

// Register 150 Bit Definitions
#define BIT_TOGGLE_EN_1_0                     0                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_0                    (0x1 << BIT_TOGGLE_EN_1_0)
#define BIT_TOGGLE_EN_1_1                     1                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_1                    (0x1 << BIT_TOGGLE_EN_1_1)
#define BIT_TOGGLE_EN_1_2                     2                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_2                    (0x1 << BIT_TOGGLE_EN_1_2)
#define BIT_TOGGLE_EN_1_3                     3                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_3                    (0x1 << BIT_TOGGLE_EN_1_3)
#define BIT_TOGGLE_EN_1_4                     4                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_4                    (0x1 << BIT_TOGGLE_EN_1_4)
#define BIT_TOGGLE_EN_1_5                     5                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_5                    (0x1 << BIT_TOGGLE_EN_1_5)
#define BIT_TOGGLE_EN_1_6                     6                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_6                    (0x1 << BIT_TOGGLE_EN_1_6)
#define BIT_TOGGLE_EN_1_7                     7                                 // PWM Out toggle enable 1
#define MASK_TOGGLE_EN_1_7                    (0x1 << BIT_TOGGLE_EN_1_7)
#define MASK_TOGGLE_EN_1                      (0xFF << BIT_TOGGLE_EN_1_0)

//------------------------------------------------------------------------------
// Register 151 (0x97) PWM_OUT_TOGGLE_EN_2
#define PWM_OUT_TOGGLE_EN_2                 0x97

// Register 151 Bit Definitions
#define BIT_TOGGLE_EN_2_0                     0                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_0                    (0x1 << BIT_TOGGLE_EN_2_0)
#define BIT_TOGGLE_EN_2_1                     1                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_1                    (0x1 << BIT_TOGGLE_EN_2_1)
#define BIT_TOGGLE_EN_2_2                     2                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_2                    (0x1 << BIT_TOGGLE_EN_2_2)
#define BIT_TOGGLE_EN_2_3                     3                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_3                    (0x1 << BIT_TOGGLE_EN_2_3)
#define BIT_TOGGLE_EN_2_4                     4                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_4                    (0x1 << BIT_TOGGLE_EN_2_4)
#define BIT_TOGGLE_EN_2_5                     5                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_5                    (0x1 << BIT_TOGGLE_EN_2_5)
#define BIT_TOGGLE_EN_2_6                     6                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_6                    (0x1 << BIT_TOGGLE_EN_2_6)
#define BIT_TOGGLE_EN_2_7                     7                                 // PWM Out toggle enable 2
#define MASK_TOGGLE_EN_2_7                    (0x1 << BIT_TOGGLE_EN_2_7)
#define MASK_TOGGLE_EN_2                      (0xFF << BIT_TOGGLE_EN_2_0)

//------------------------------------------------------------------------------
// Register 152 (0x98) PWM_OUT_TOGGLE_EN_3
#define PWM_OUT_TOGGLE_EN_3                 0x98

// Register 152 Bit Definitions
#define BIT_TOGGLE_EN_3_0                     0                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_0                    (0x1 << BIT_TOGGLE_EN_3_0)
#define BIT_TOGGLE_EN_3_1                     1                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_1                    (0x1 << BIT_TOGGLE_EN_3_1)
#define BIT_TOGGLE_EN_3_2                     2                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_2                    (0x1 << BIT_TOGGLE_EN_3_2)
#define BIT_TOGGLE_EN_3_3                     3                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_3                    (0x1 << BIT_TOGGLE_EN_3_3)
#define BIT_TOGGLE_EN_3_4                     4                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_4                    (0x1 << BIT_TOGGLE_EN_3_4)
#define BIT_TOGGLE_EN_3_5                     5                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_5                    (0x1 << BIT_TOGGLE_EN_3_5)
#define BIT_TOGGLE_EN_3_6                     6                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_6                    (0x1 << BIT_TOGGLE_EN_3_6)
#define BIT_TOGGLE_EN_3_7                     7                                 // PWM Out toggle enable 3
#define MASK_TOGGLE_EN_3_7                    (0x1 << BIT_TOGGLE_EN_3_7)
#define MASK_TOGGLE_EN_3                      (0xFF << BIT_TOGGLE_EN_3_0)

//------------------------------------------------------------------------------
// Register 153 (0x99) PWM_OUT_TOGGLE_EN_4
#define PWM_OUT_TOGGLE_EN_4                 0x99

// Register 153 Bit Definitions
#define BIT_TOGGLE_EN_4_0                     0                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_0                    (0x1 << BIT_TOGGLE_EN_4_0)
#define BIT_TOGGLE_EN_4_1                     1                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_1                    (0x1 << BIT_TOGGLE_EN_4_1)
#define BIT_TOGGLE_EN_4_2                     2                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_2                    (0x1 << BIT_TOGGLE_EN_4_2)
#define BIT_TOGGLE_EN_4_3                     3                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_3                    (0x1 << BIT_TOGGLE_EN_4_3)
#define BIT_TOGGLE_EN_4_4                     4                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_4                    (0x1 << BIT_TOGGLE_EN_4_4)
#define BIT_TOGGLE_EN_4_5                     5                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_5                    (0x1 << BIT_TOGGLE_EN_4_5)
#define BIT_TOGGLE_EN_4_6                     6                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_6                    (0x1 << BIT_TOGGLE_EN_4_6)
#define BIT_TOGGLE_EN_4_7                     7                                 // PWM Out toggle enable 4
#define MASK_TOGGLE_EN_4_7                    (0x1 << BIT_TOGGLE_EN_4_7)
#define MASK_TOGGLE_EN_4                      (0xFF << BIT_TOGGLE_EN_4_0)

//------------------------------------------------------------------------------
// Register 154 (0x9A) PWM_OUT_TOGGLE_EN_5
#define PWM_OUT_TOGGLE_EN_5                 0x9A

// Register 154 Bit Definitions
#define BIT_TOGGLE_EN_5_0                     0                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_0                    (0x1 << BIT_TOGGLE_EN_5_0)
#define BIT_TOGGLE_EN_5_1                     1                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_1                    (0x1 << BIT_TOGGLE_EN_5_1)
#define BIT_TOGGLE_EN_5_2                     2                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_2                    (0x1 << BIT_TOGGLE_EN_5_2)
#define BIT_TOGGLE_EN_5_3                     3                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_3                    (0x1 << BIT_TOGGLE_EN_5_3)
#define BIT_TOGGLE_EN_5_4                     4                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_4                    (0x1 << BIT_TOGGLE_EN_5_4)
#define BIT_TOGGLE_EN_5_5                     5                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_5                    (0x1 << BIT_TOGGLE_EN_5_5)
#define BIT_TOGGLE_EN_5_6                     6                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_6                    (0x1 << BIT_TOGGLE_EN_5_6)
#define BIT_TOGGLE_EN_5_7                     7                                 // PWM Out toggle enable 5
#define MASK_TOGGLE_EN_5_7                    (0x1 << BIT_TOGGLE_EN_5_7)
#define MASK_TOGGLE_EN_5                      (0xFF << BIT_TOGGLE_EN_5_0)

//------------------------------------------------------------------------------
// Register 155 (0x9B) PWM_OUT_TOGGLE_EN_6
#define PWM_OUT_TOGGLE_EN_6                 0x9B

// Register 155 Bit Definitions
#define BIT_TOGGLE_EN_6_0                     0                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_0                    (0x1 << BIT_TOGGLE_EN_6_0)
#define BIT_TOGGLE_EN_6_1                     1                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_1                    (0x1 << BIT_TOGGLE_EN_6_1)
#define BIT_TOGGLE_EN_6_2                     2                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_2                    (0x1 << BIT_TOGGLE_EN_6_2)
#define BIT_TOGGLE_EN_6_3                     3                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_3                    (0x1 << BIT_TOGGLE_EN_6_3)
#define BIT_TOGGLE_EN_6_4                     4                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_4                    (0x1 << BIT_TOGGLE_EN_6_4)
#define BIT_TOGGLE_EN_6_5                     5                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_5                    (0x1 << BIT_TOGGLE_EN_6_5)
#define BIT_TOGGLE_EN_6_6                     6                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_6                    (0x1 << BIT_TOGGLE_EN_6_6)
#define BIT_TOGGLE_EN_6_7                     7                                 // PWM Out toggle enable 6
#define MASK_TOGGLE_EN_6_7                    (0x1 << BIT_TOGGLE_EN_6_7)
#define MASK_TOGGLE_EN_6                      (0xFF << BIT_TOGGLE_EN_6_0)

//------------------------------------------------------------------------------
// Register 156 (0x9C) PWM_OUT_TOGGLE_EN_7
#define PWM_OUT_TOGGLE_EN_7                 0x9C

// Register 156 Bit Definitions
#define BIT_TOGGLE_EN_7_0                     0                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_0                    (0x1 << BIT_TOGGLE_EN_7_0)
#define BIT_TOGGLE_EN_7_1                     1                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_1                    (0x1 << BIT_TOGGLE_EN_7_1)
#define BIT_TOGGLE_EN_7_2                     2                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_2                    (0x1 << BIT_TOGGLE_EN_7_2)
#define BIT_TOGGLE_EN_7_3                     3                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_3                    (0x1 << BIT_TOGGLE_EN_7_3)
#define BIT_TOGGLE_EN_7_4                     4                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_4                    (0x1 << BIT_TOGGLE_EN_7_4)
#define BIT_TOGGLE_EN_7_5                     5                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_5                    (0x1 << BIT_TOGGLE_EN_7_5)
#define BIT_TOGGLE_EN_7_6                     6                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_6                    (0x1 << BIT_TOGGLE_EN_7_6)
#define BIT_TOGGLE_EN_7_7                     7                                 // PWM Out toggle enable 7
#define MASK_TOGGLE_EN_7_7                    (0x1 << BIT_TOGGLE_EN_7_7)
#define MASK_TOGGLE_EN_7                      (0xFF << BIT_TOGGLE_EN_7_0)

//------------------------------------------------------------------------------
// Register 157 (0x9D) PWM_OUT_CLR_EN
#define PWM_OUT_CLR_EN                      0x9D

// Register 157 Bit Definitions
#define BIT_CLR_EN_0                          0                                 // PWM Out clear enable
#define MASK_CLR_EN_0                         (0x1 << BIT_CLR_EN_0)
#define BIT_CLR_EN_1                          1                                 // PWM Out clear enable
#define MASK_CLR_EN_1                         (0x1 << BIT_CLR_EN_1)
#define BIT_CLR_EN_2                          2                                 // PWM Out clear enable
#define MASK_CLR_EN_2                         (0x1 << BIT_CLR_EN_2)
#define BIT_CLR_EN_3                          3                                 // PWM Out clear enable
#define MASK_CLR_EN_3                         (0x1 << BIT_CLR_EN_3)
#define BIT_CLR_EN_4                          4                                 // PWM Out clear enable
#define MASK_CLR_EN_4                         (0x1 << BIT_CLR_EN_4)
#define BIT_CLR_EN_5                          5                                 // PWM Out clear enable
#define MASK_CLR_EN_5                         (0x1 << BIT_CLR_EN_5)
#define BIT_CLR_EN_6                          6                                 // PWM Out clear enable
#define MASK_CLR_EN_6                         (0x1 << BIT_CLR_EN_6)
#define BIT_CLR_EN_7                          7                                 // PWM Out clear enable
#define MASK_CLR_EN_7                         (0x1 << BIT_CLR_EN_7)
#define MASK_CLR_EN                           (0xFF << BIT_CLR_EN_0)

//------------------------------------------------------------------------------
// Register 158 (0x9E) PWM_CTRL_BL_CMP8
#define PWM_CTRL_BL_CMP8                    0x9E

// Register 158 Bit Definitions
#define BIT_CTRL_BL_CMP8_0                    0                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_0                   (0x1 << BIT_CTRL_BL_CMP8_0)
#define BIT_CTRL_BL_CMP8_1                    1                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_1                   (0x1 << BIT_CTRL_BL_CMP8_1)
#define BIT_CTRL_BL_CMP8_2                    2                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_2                   (0x1 << BIT_CTRL_BL_CMP8_2)
#define BIT_CTRL_BL_CMP8_3                    3                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_3                   (0x1 << BIT_CTRL_BL_CMP8_3)
#define BIT_CTRL_BL_CMP8_4                    4                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_4                   (0x1 << BIT_CTRL_BL_CMP8_4)
#define BIT_CTRL_BL_CMP8_5                    5                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_5                   (0x1 << BIT_CTRL_BL_CMP8_5)
#define BIT_CTRL_BL_CMP8_6                    6                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_6                   (0x1 << BIT_CTRL_BL_CMP8_6)
#define BIT_CTRL_BL_CMP8_7                    7                                 // Control block CMP8 value. 0 continuous, 1 one shot, 2-255 <N
#define MASK_CTRL_BL_CMP8_7                   (0x1 << BIT_CTRL_BL_CMP8_7)
#define MASK_CTRL_BL_CMP8                     (0xFF << BIT_CTRL_BL_CMP8_0)

//------------------------------------------------------------------------------
// Register 159 (0x9F) PWM_INIT
#define PWM_INIT                            0x9F

// Register 159 Bit Definitions
#define BIT_INIT_0                            0                                 // PWM Initialisation register
#define MASK_INIT_0                           (0x1 << BIT_INIT_0)
#define BIT_INIT_1                            1                                 // PWM Initialisation register
#define MASK_INIT_1                           (0x1 << BIT_INIT_1)
#define BIT_INIT_2                            2                                 // PWM Initialisation register
#define MASK_INIT_2                           (0x1 << BIT_INIT_2)
#define BIT_INIT_3                            3                                 // PWM Initialisation register
#define MASK_INIT_3                           (0x1 << BIT_INIT_3)
#define BIT_INIT_4                            4                                 // PWM Initialisation register
#define MASK_INIT_4                           (0x1 << BIT_INIT_4)
#define BIT_INIT_5                            5                                 // PWM Initialisation register
#define MASK_INIT_5                           (0x1 << BIT_INIT_5)
#define BIT_INIT_6                            6                                 // PWM Initialisation register
#define MASK_INIT_6                           (0x1 << BIT_INIT_6)
#define BIT_INIT_7                            7                                 // PWM Initialisation register
#define MASK_INIT_7                           (0x1 << BIT_INIT_7)
#define MASK_INIT                             (0xFF << BIT_INIT_0)

#endif // __FT51_PWM_REGISTERS_H__